#!/bin/sh
# ----------------------------------------------------------------------------
# /tmp/preinstall.sh - minidlna preinstallation script
#
# Creation   : 2010-01-02 jk
# Last update: $Id: preinstall.sh 15 2010-01-02 18:50:36Z jk $
#
# Copyright (c) 2010 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# set packages name
packageName=minidlna

# define variables
needed_base='1.5.4'

# ----------------------------------------------------------------------------
# Functions
# ----------------------------------------------------------------------------

checkRequirement()
{
    local pName=$1
    local pVersion=$2
    # check whether following package is installed
    installed_version=`/var/install/bin/check-version $pName pVersion`
    case ${installed_version} in
        not-installed|new )
            # wrong version
            mecho -warn "Required $pName $pVersion or newer not installed - Failure!"
         packageMissing=true
            ;;
        * )
            # installed or newer installed
            mecho -info "Required $pName $pVersion newer or installed     - OK"
            ;;
    esac
}


# ----------------------------------------------------------------------------
# MAIN - Start Preinstallation
# ----------------------------------------------------------------------------
/usr/local/bin/colecho "Running preinstallation script ..." gn

#------------------------------------------------------------------------------
# check base version
#------------------------------------------------------------------------------
if [ ! -f /var/install/bin/check-version ] ||
   [ `/var/install/bin/check-version base $needed_base` == "new" ]
then
    colecho "The version of eisfair must be $needed_base or higher." rd w brinv
    colecho "Please update your eisfair system first." rd w brinv
    anykey   
    exit 1
fi

#------------------------------------------------------------------------------
# check for required packages and libs
#------------------------------------------------------------------------------

# include eislib
# Achtung: eislib darf erst nach base version check geladen werden; und erst ab hier mecheo
. /var/install/include/eislib

# define package missing variable
packageMissing=false

# check whether required packages are missing
checkRequirement libexif 0.1.0
checkRequirement libjpeg 0.6.2
checkRequirement id3lib 0.1.0
checkRequirement libflac 0.1.1
checkRequirement libvorbis 0.1.4
checkRequirement sqlite 0.2.0
checkRequirement ffmpeg 0.7.1

# print error message if package missing
if ${packageMissing}
then
    mecho
    mecho -warn "'$packageName' requires one or more package(s) not installed yet."
    mecho -warn "Please update/install the required package(s) first!"
    mecho
else
    mecho
    mecho -info "All required packages/libs are installed and up to date"
    mecho
fi

# ----------------------------------------------------------------------------
# Update system
# ----------------------------------------------------------------------------

if [ -f /var/install/deinstall/${packageName} ]
then
    mecho -info "Update: De-install old $packageName version"
    /var/install/deinstall/${packageName} update
fi

mecho -info "Pre-Installation script finished"

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------

