#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/minidlna-update.sh - paramater update script
#
# Creation   : 2010-01-02 jk
# Last update: $Id: minidlna-update.sh 15 2010-01-02 18:50:36Z jk $
#
# Copyright (c) 2010 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/minidlna-update-trace$$.log
#set -x

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=minidlna

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_MINIDLNA='no'
MINIDLNA_PORT='8200'
MINIDLNA_NW_INTERFACE='eth0'
MINIDLNA_MEDIA_N='1'
MINIDLNA_MEDIA_1_DIR='/data'
MINIDLNA_MEDIA_1_CONTENT='All'
MINIDLNA_NAME='Media'
MINIDLNA_ALBUM_NAMES='Cover.jpg/cover.jpg/Album.jpg/album.jpg/Thumb.jpg/thumb.jpg'                            
MINIDLNA_INOTIFY='no'
MINIDLNA_ENABLE_TIVO='no'
MINIDLNA_STRICT_DLNA='no'
MINIDLNA_WEB_URL=''
MINIDLNA_NTFY_INTERVAL='900'
MINIDLNA_SERIAL='12345678'
MINIDLNA_MODEL_NUMBER='1'
#
MINIDLNA_DO_DEBUG='no' 



# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/${packageName} ]
    then
        . /etc/config.d/${packageName}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ${packageName} "2010-01-02" "jk"
    # ------------------------------------------------------------------------

    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_MINIDLNA" "Start MINIDLNA Server? Use: yes or no"
    printvar "MINIDLNA_PORT" "port for HTTP traffic"
    printvar "MINIDLNA_NW_INTERFACE" "network interface to bind"
    printvar "MINIDLNA_MEDIA_N" "Amount of Directories to scan"

    if [ $MINIDLNA_MEDIA_N -eq 0 ]
    then
        imax=1
    else
        imax=$MINIDLNA_MEDIA_N
    fi

    idx=1
    while [ "$idx" -le $imax ]
    do
        eval pDir='$MINIDLNA_MEDIA_'$idx'_DIR'
        printvar "MINIDLNA_MEDIA_${idx}_DIR" "Directory you want scan"
        printvar "MINIDLNA_MEDIA_${idx}_CONTENT" "Content of Directory"
        idx=`/usr/bin/expr $idx + 1`
    done

    printvar "MINIDLNA_NAME" "Name that shows up on your clients"
    printvar "MINIDLNA_ALBUM_NAMES" "List of file names to check for when searching for album"
    printvar "MINIDLNA_INOTIFY" "Enable monitoring to automatically discover new files? Att: Works only with kernel 2.6"
    printvar "MINIDLNA_ENABLE_TIVO" "Enable support for streaming .jpg and .mp3 files to a TiVo supporting HMO?"
    printvar "MINIDLNA_STRICT_DLNA" "Strictly adhere to DLNA standards?"
    printvar "MINIDLNA_WEB_URL" "Presentation url is http address on port 80"
    printvar "MINIDLNA_NTFY_INTERVAL" "Notify interval in seconds. Default: 895 seconds."
    printvar "MINIDLNA_SERIAL" "Serial number the daemon will report to clients in its XML description"
    printvar "MINIDLNA_MODEL_NUMBER" "Model number the daemon will report to clients in its XML description"
    printvar "MINIDLNA_DO_DEBUG" "do debug (only for development)"

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{

# create file check.d

    printgpl -check ${packageName} '2010-01-02' 'jk' >/etc/check.d/${packageName}
    cat >> /etc/check.d/${packageName} <<EOFG

# Variable                OPT_VARIABLE      VARIABLE_N          VALUE
START_MINIDLNA            -                 -                   YESNO
MINIDLNA_PORT             START_MINIDLNA    -                   PORT
MINIDLNA_NW_INTERFACE     START_MINIDLNA    -                   ETH_BASE_DEV_NAME
MINIDLNA_MEDIA_N          START_MINIDLNA    -                   NUMERIC
MINIDLNA_MEDIA_%_DIR      START_MINIDLNA    MINIDLNA_MEDIA_N    ABS_PATH
MINIDLNA_MEDIA_%_CONTENT  START_MINIDLNA    MINIDLNA_MEDIA_N    MINIDLNA_CONTENT
MINIDLNA_NAME             START_MINIDLNA    -                   MINIDLNA_WEBNAME
MINIDLNA_ALBUM_NAMES      START_MINIDLNA    -                   NOTEMPTY
MINIDLNA_INOTIFY          START_MINIDLNA    -                   YESNO
MINIDLNA_ENABLE_TIVO      START_MINIDLNA    -                   YESNO
MINIDLNA_STRICT_DLNA      START_MINIDLNA    -                   YESNO
MINIDLNA_WEB_URL          START_MINIDLNA    -                   NONE
MINIDLNA_NTFY_INTERVAL    START_MINIDLNA    -                   NUMERIC
MINIDLNA_SERIAL           START_MINIDLNA    -                   NUMERIC
MINIDLNA_MODEL_NUMBER     START_MINIDLNA    -                   NUMERIC
MINIDLNA_DO_DEBUG         START_MINIDLNA    -                   YESNO
EOFG

# Set rights for check.d file
chmod 0600 /etc/check.d/${packageName}
chown root /etc/check.d/${packageName}

printgpl -check_exp ${packageName} '2010-01-26' 'jk' >/etc/check.d/${packageName}.exp
cat >> /etc/check.d/${packageName}.exp <<EOFG

MINIDLNA_NUMERIC    = '1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|19|19|20'
                    : 'only fsfs or bdb are allowed'

MINIDLNA_CONTENT    = 'All|Audio|Video|Photo'
                    : 'only All, Audio, Video, Photo are allwod'

MINIDLNA_WEBNAME    = '[[:alnum:]](_|-?[[:alnum:]])*'
                    : 'wrong name, only letters, numbers, minus signs
                       and underscores are allowed;
                       no leading or trailing minus signs'

EOFG

# Set rights for check.exp file
chmod 0600 /etc/check.d/${packageName}.exp
chown root /etc/check.d/${packageName}.exp

# printgpl -check_ext ${packageName} '2010-01-26' 'jk' >/etc/check.d/${packageName}.ext
# cat >> /etc/check.d/${packageName}.ext <<EOFG
#
# EOFG

# Set rights for check.ext file
# chmod 0600 /etc/check.d/${packageName}.ext
# chown root /etc/check.d/${packageName}.ext
# create file check.ext - not used yet

}

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file
if [ -f /etc/config.d/${packageName} ]
then
    mecho -info -n "Updating configuration."
else
    mecho -info -n "Creating configuration."
fi

makeConfigFile /etc/default.d/${packageName}

# Update from old version
mecho -info -n "."
renameOldVariables

# Write new config file
mecho -info -n "."
makeConfigFile /etc/config.d/${packageName}

# Write check.d file
mecho -info -n "."
makeCheckFile

mecho -info " Finished."

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
